%define prefix /usr
%define name hdsentinel
%define version 008
%define release %mkrel 1
%define url http://www.hdsentinel.com/hard_disk_sentinel_linux.php

Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	Freeware
Group:		Monitoring
URL:		%{url}
#ifarch x86_64
Source1:	http://www.hdsentinel.com/hdslin/%{name}_%{version}_x64.tar.xz
#else
Source2:	http://www.hdsentinel.com/hdslin/%{name}_%{version}.tar.xz
#endif
Summary:	Hard Disk Sentinel Linux Edition
BuildRoot:	%{_tmppath}/%{name}-buildroot
Obsoletes:	%name < %version

%description
Hard Disk Sentinel -  examine the temperature and health information 
(and more) of IDE, S-ATA (SATA II also), SCSI and USB hard disks 
connected to motherboard or external controller cards.

List of features
* display hard disk / solid state disk information on the terminal 
* create comprehensive report about the disk system, including both hard 
  disk and SSD specific features (for example, media rotation rate, TRIM command, etc.) 
* display and manage acoustic setting of hard disks (on supported USB disks also) 
* offers outputs for both users and scripts/other applications to process
 
The following information are displayed:
* detected hard disk number and device name (for example /dev/sda) 
* size, model ID, serial number, revision and interface of all detected hard disks 
* temperature, health and performance values 
* power on time (days, hour, minutes - if supported)
  Note: this is for informational purposes only, the value displayed under Windows 
  (after some minutes of testing) may be more accurate 
* acoustic management settings (if supported and -aam or -setaam option is used 

Command line switches
The switches are NOT case sensitive. Upper and lower case can be used to specify them.
* -h - displays help and usage information 
* -r [report file] - automatically save report to filename (default: report.txt) 
* -dump - dump report to stdout (can be used with -xml to dump XML output instead of text) 
* -xml - create and save XML report instead of TXT 
* -solid - solid output (drive, tempC, health%, power on hours, model, S/N, size) 
* -verbose - detailed detection information and save temporary files (only for debug purposes) 
* -aam - display acoustic management settings (current and recommended level) 
* -setaam drive_num|ALL level(hex)80-FE|QUIET|LOUD - set acoustic level on drive 0..n (or all)
   80 or QUIET is the lowest (most silent) setting, FE or LOUD is the highest (fastest) setting
   For example: hdsentinel -setaam 0 loud - Configures drive 0 to fastest (loud) setting. Same 
   as hdsentinel -setaam 0 FE 

Please send saved XML or TXT reports, questions or ideas to info@hdsentinel.com to help 
improving this tool.


%install
rm -rf $RPM_BUILD_ROOT

mkdir -p %{buildroot}%{_bindir}

%ifarch x86_64
tar xf %SOURCE1 -C $RPM_BUILD_ROOT/%{_bindir} 
%else
tar xf %SOURCE2 -C $RPM_BUILD_ROOT/%{_bindir}
%endif

%__chmod 0755 %{buildroot}%{_bindir}/HDSentinel

#generate help file
mkdir -p %{buildroot}%{_docdir}/%{name}
cat > %{buildroot}%{_docdir}/%{name}/examples << EOF
Examples
Optimize complete system for silence: hdsentinel -setaam all quiet
Optimize complete system for high performance (but louder disk access): 
 hdsentinel -setaam all loud

Select a balanced level between silence and performance on drive 0: 
 hdsentinel -setaam 0 C0

 Note: some disks do not support balanced settings and they may select the 
       most silent (80) or high performance (FE) setting instead.
 Please start hsentinel without parameters to see drive assignments 
 (eg. /dev/sda) to drive indexes.
Due to the high amount of requests, it is possible to create minimal output 
which can be easily parsed and processed for further use. Some examples are:
List disk drives, temperature (in Celsius), health %, power on hours, disk model, 
disk serial, size: 
 hdsentinel -solid. Sample results:
 
  /dev/sda 42   3  4830 WDC_WD800JD-8LSA0   WD-WMAM9F937837   76324
  /dev/sdb 30 100  6128 ST3250624A          5ND3J94R         238472
  /dev/sdc 46 100 10982 WDC_WD2500JS-00MHB0 WD-WCANK8705209  238475
  /dev/sdd  ?   ?     ? GENERIC_CF_READER   9999                  0
  /dev/sde  ?   ?     ? GENERIC_SD_READER   9999               1963

List only temperature, drive, size:
 hdsentinel -solid | awk '{print $2, $1, $7}'
 
  42 /dev/sda 76324 
  30 /dev/sdb 238472
  46 /dev/sdc 238475
  ? /dev/sdd 0      
  ? /dev/sde 1963   

List only temperature, drive, model ID, highest temperature on top, drives without 
temperature information (for example card readers) removed:
 hdsentinel -solid | awk '{print $2, $1, $5}' | grep -v "^?" | sort -nr
 
  46 /dev/sdc WDC_WD2500JS-00MHB0
  42 /dev/sda WDC_WD800JD-8LSA0  
  30 /dev/sdb ST3250624A         

List only health, temperature, drive, lowest health on top, drives without temperature 
information (for example card readers) removed:
 hdsentinel -solid | awk '{print $3, $2, $1}' | grep -v "^?" | sort -n
 
  3 42 /dev/sda  
  100 30 /dev/sdb
  100 46 /dev/sdc

Note that the spaces in hard disk model ID and serial number are replaced with underscore (_).

If you have any ideas, thoughts about the automatic processing of output or if you have 
complete script(s) you want to share with other users, please send a mail and it will be 
published on this page with the name and credits of the sender of the script.

EOF

%files
%defattr(-,root,root)
%{_bindir}/HDSentinel
%{_docdir}/%{name}/examples

%clean
rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/%{name}_%{version}

%changelog
* Sun Mar 18 2012 Neal <nealbrks0 at gmail dot com> 008-1pclos2012
- process

* Sat Mar 17 2012 leiche <meisssw01 at gmail.com> 008-1pclos2012
- initial package for both arch
